#include "TYW_stdint.h"
/*3A外发12片*2路*/
void TPS2HB35_SetOutput3A_OUT1(uint8_t state);
void TPS2HB35_SetOutput3A_OUT2(uint8_t state);
void TPS2HB35_SetOutput3A_OUT3(uint8_t state);
void TPS2HB35_SetOutput3A_OUT4(uint8_t state);
void TPS2HB35_SetOutput3A_OUT5(uint8_t state);
void TPS2HB35_SetOutput3A_OUT6(uint8_t state);
void TPS2HB35_SetOutput3A_OUT7(uint8_t state);
void TPS2HB35_SetOutput3A_OUT8(uint8_t state);
void TPS2HB35_SetOutput3A_OUT9(uint8_t state);
void TPS2HB35_SetOutput3A_OUT10(uint8_t state);
void TPS2HB35_SetOutput3A_OUT11(uint8_t state);
void TPS2HB35_SetOutput3A_OUT12(uint8_t state);
void TPS2HB35_SetOutput3A_OUT13(uint8_t state);
void TPS2HB35_SetOutput3A_OUT14(uint8_t state);
void TPS2HB35_SetOutput3A_OUT15(uint8_t state);
void TPS2HB35_SetOutput3A_OUT16(uint8_t state);
void TPS2HB35_SetOutput3A_OUT17(uint8_t state);
void TPS2HB35_SetOutput3A_OUT18(uint8_t state);
void TPS2HB35_SetOutput3A_OUT19(uint8_t state);
void TPS2HB35_SetOutput3A_OUT20(uint8_t state);
void TPS2HB35_SetOutput3A_OUT21(uint8_t state);
void TPS2HB35_SetOutput3A_OUT22(uint8_t state);
void TPS2HB35_SetOutput3A_OUT23(uint8_t state);
void TPS2HB35_SetOutput3A_OUT24(uint8_t state);
/*5A外发10片*2路*/
void TPS2HB35_SetOutput5A_OUT1(uint8_t state);
void TPS2HB35_SetOutput5A_OUT2(uint8_t state);
void TPS2HB35_SetOutput5A_OUT3(uint8_t state);
void TPS2HB35_SetOutput5A_OUT4(uint8_t state);
void TPS2HB35_SetOutput5A_OUT5(uint8_t state);
void TPS2HB35_SetOutput5A_OUT6(uint8_t state);
void TPS2HB35_SetOutput5A_OUT7(uint8_t state);
void TPS2HB35_SetOutput5A_OUT8(uint8_t state);
void TPS2HB35_SetOutput5A_OUT9(uint8_t state);
void TPS2HB35_SetOutput5A_OUT10(uint8_t state);
void TPS2HB35_SetOutput5A_OUT11(uint8_t state);
void TPS2HB35_SetOutput5A_OUT12(uint8_t state);
void TPS2HB35_SetOutput5A_OUT13(uint8_t state);
void TPS2HB35_SetOutput5A_OUT14(uint8_t state);
void TPS2HB35_SetOutput5A_OUT15(uint8_t state);
void TPS2HB35_SetOutput5A_OUT16(uint8_t state);
void TPS2HB35_SetOutput5A_OUT17(uint8_t state);
void TPS2HB35_SetOutput5A_OUT18(uint8_t state);
void TPS2HB35_SetOutput5A_OUT19(uint8_t state);
void TPS2HB35_SetOutput5A_OUT20(uint8_t state);
/*10A外发4片*2路*/
void TPS2HB35_SetOutput10A_OUT1(uint8_t state);
void TPS2HB35_SetOutput10A_OUT2(uint8_t state);
void TPS2HB35_SetOutput10A_OUT3(uint8_t state);
void TPS2HB35_SetOutput10A_OUT4(uint8_t state);
void TPS2HB35_SetOutput10A_OUT5(uint8_t state);
void TPS2HB35_SetOutput10A_OUT6(uint8_t state);
void TPS2HB35_SetOutput10A_OUT7(uint8_t state);
void TPS2HB35_SetOutput10A_OUT8(uint8_t state);
/*15A外发14片*1路*/
void TPS2HB35_SetOutput15A_OUT1(uint8_t state);
void TPS2HB35_SetOutput15A_OUT2(uint8_t state);
void TPS2HB35_SetOutput15A_OUT3(uint8_t state);
void TPS2HB35_SetOutput15A_OUT4(uint8_t state);
void TPS2HB35_SetOutput15A_OUT5(uint8_t state);
void TPS2HB35_SetOutput15A_OUT6(uint8_t state);
void TPS2HB35_SetOutput15A_OUT7(uint8_t state);
void TPS2HB35_SetOutput15A_OUT8(uint8_t state);
void TPS2HB35_SetOutput15A_OUT9(uint8_t state);
void TPS2HB35_SetOutput15A_OUT10(uint8_t state);
void TPS2HB35_SetOutput15A_OUT11(uint8_t state);
void TPS2HB35_SetOutput15A_OUT12(uint8_t state);
void TPS2HB35_SetOutput15A_OUT13(uint8_t state);
void TPS2HB35_SetOutput15A_OUT14(uint8_t state);